# SeaHash

[![CI](https://github.com/RealOrangeOne/seahash-py/actions/workflows/ci.yml/badge.svg)](https://github.com/RealOrangeOne/seahash-py/actions/workflows/ci.yml)

Python bindings to [`seahash`](https://docs.rs/seahash/).
